module TaggableController
  extend ActiveSupport::Concern

  included do
    before_action :authenticate_user!, only: [:tagging, :untagging]
    before_action :set_user_tags, only: [:tagging, :untagging]
  end

  # POST /v1/learning_objects/1/tagging
  # POST /v1/learning_objects/1/tagging.json
  def tagging
    current_user.tag(taggable, with: @user_tags.map(&:name) << tag_params[:name], on: :tags)
    render json: taggable, status: :created
  end

  # DELETE /v1/learning_objects/1/untagging
  # DELETE /v1/learning_objects/1/untagging.json
  def untagging
    current_user.tag(taggable, with: @user_tags.map(&:name).select { |tag| tag != tag_params[:name] }, on: :tags)
    render json: taggable, status: :ok
  end

  protected

  def taggable
    raise NotImplementedError
  end

  def tag_params
    params.require(:tag).permit(:name)
  end

  def set_user_tags
    @user_tags = taggable.owner_tags_on(current_user, :tags)
  end
end
