module Reputationable
  extend ActiveSupport::Concern

  def submitted_objects
    learning_objects.count
  end

  def reviews_score_average
    scores = learning_objects.map(&:review_ratings_average)

    return 0.0 if scores.size == 0

    scores.inject(0.0) { |a, e| a + e }.to_f / scores.size.to_f
  end

  def learning_objects_in_best_collections
    return 0.0 if collections.nil?

    average = Collection.average(:score)
    collections.where('score >= ?', average).count
  end

  def learning_objects_best_score
    learning_objects.maximum(:score)
  end

  def learning_objects_average_score
    learning_objects.average(:score)
  end

  def review_approval_average
    return 0.0 if reviews.nil? || reviews.size < 5

    array = reviews.map(&:rates_percentage)
    array.inject(0.0) { |a, e| a + e } / array.size
  end

  def followers_count
    followers.count
  end

  def learning_objects_recently_submitted
    return 0.0 if learning_objects.nil?

    learning_objects.where('created_at >= ?', (Time.now - 2.months)).count
  end

  def collections_score_average
    return 0.0 if collections.nil? || collections.where(privacy: 'public').count == 0

    collections.where(privacy: 'public').average(:score)
  end
end
